==> haskell-hledger-lib-1.14.1-41-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hledger-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger-lib
version: 1.14.1
id: hledger-lib-1.14.1-EToCLbsW299JEHerEr5SnW
key: hledger-lib-1.14.1-EToCLbsW299JEHerEr5SnW
license: GPL-3.0-only
maintainer: Simon Michael <simon@joyful.com>
author: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Core data types, parsers and functionality for the hledger accounting tools
description:
    This is a reusable library containing hledger'\''s core functionality.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance
abi: e71e1581e1ddd47c2d68602c1d575691
exposed: True
exposed-modules:
    Hledger Hledger.Data Hledger.Data.Account Hledger.Data.AccountName
    Hledger.Data.Amount Hledger.Data.Commodity Hledger.Data.Dates
    Hledger.Data.Journal Hledger.Data.Ledger Hledger.Data.MarketPrice
    Hledger.Data.Period Hledger.Data.PeriodicTransaction
    Hledger.Data.Posting Hledger.Data.RawOptions
    Hledger.Data.StringFormat Hledger.Data.Timeclock
    Hledger.Data.Transaction Hledger.Data.TransactionModifier
    Hledger.Data.Types Hledger.Query Hledger.Read Hledger.Read.Common
    Hledger.Read.CsvReader Hledger.Read.JournalReader
    Hledger.Read.TimeclockReader Hledger.Read.TimedotReader
    Hledger.Reports Hledger.Reports.BalanceHistoryReport
    Hledger.Reports.BalanceReport Hledger.Reports.BudgetReport
    Hledger.Reports.EntriesReport Hledger.Reports.MultiBalanceReports
    Hledger.Reports.PostingsReport Hledger.Reports.ReportOptions
    Hledger.Reports.ReportTypes Hledger.Reports.TransactionsReports
    Hledger.Utils Hledger.Utils.Color Hledger.Utils.Debug
    Hledger.Utils.Parse Hledger.Utils.Regex Hledger.Utils.String
    Hledger.Utils.Test Hledger.Utils.Text Hledger.Utils.Tree
    Hledger.Utils.UTF8IOCompat Text.Tabular.AsciiWide
hidden-modules: Text.Megaparsec.Custom Paths_hledger_lib
import-dirs: /usr/lib/ghc-8.6.5/site-local/hledger-lib-1.14.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hledger-lib-1.14.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hledger-lib-1.14.1
hs-libraries: HShledger-lib-1.14.1-EToCLbsW299JEHerEr5SnW
depends:
    Decimal-0.5.1-H2kU9PQoNIhDDGeZUlyXId
    Glob-0.10.0-53dKAknqnvt9l4cJJo9cnr
    ansi-terminal-0.9.1-7greAUREMxf1pgDTp3Pb1X array-0.5.3.0
    base-4.12.0.0 base-compat-batteries-0.10.5-KvYjlXLhf5S8nu3CG2PCKk
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    call-stack-0.1.0-J1eWgTNOnM4IGVyeW0v2YZ
    cassava-0.5.1.0-9dZezC1UxDTDHdgPv7p9Xy
    cassava-megaparsec-2.0.0-B7Z4umIU9AKLFsOLjbRH5f
    cmdargs-0.10.20-HFOpHQTj4XE8aEWjoI1u1 containers-0.6.0.1
    data-default-0.7.1.1-FxanJFkeYAJQ1iDuwiDPz deepseq-1.4.4.0
    directory-1.3.3.0 easytest-0.2.1-Fvr3pELpRTdDli5viSGCl3
    extra-1.6.17-Gz9tBYjY7l0FvUCaVAXuat
    file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke filepath-1.4.2.1
    hashtables-1.2.3.4-27kFAI3EbWD5WuakaktwlQ
    megaparsec-7.0.5-7nNPtHGYzPNBh8epow1r1w mtl-2.2.2
    old-time-1.1.0.3-HsoRJMkCHriE79r63Cxfu4 parsec-3.1.13.0
    parser-combinators-1.2.0-2keeVZyMyoBVuECNB2kOs
    pretty-show-1.9.5-4s9IVBWSe01IF3L4DDRCg8
    regex-tdfa-1.2.3.2-1zrqdepzFAcLwdkKMIY7hi
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji
    split-0.2.3.3-IbK4kxLa0sUBqxIH6ONm60
    tabular-0.2.2.7-FYVnBEx3xwsDpJzPJOu9nb template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    uglymemo-0.1.0.1-29YPrKIZHiw2b7IPpRwZ9C
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-hledger-lib/html/hledger-lib.haddock
haddock-html: /usr/share/doc/haskell-hledger-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hledger-lib-1.14.1-43-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hledger-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger-lib
version: 1.14.1
id: hledger-lib-1.14.1-CCFlRT6cyZWCBvFAl8C9cX
key: hledger-lib-1.14.1-CCFlRT6cyZWCBvFAl8C9cX
license: GPL-3.0-only
maintainer: Simon Michael <simon@joyful.com>
author: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Core data types, parsers and functionality for the hledger accounting tools
description:
    This is a reusable library containing hledger'\''s core functionality.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance
abi: c4d8db0a154871f161c879481492abbe
exposed: True
exposed-modules:
    Hledger Hledger.Data Hledger.Data.Account Hledger.Data.AccountName
    Hledger.Data.Amount Hledger.Data.Commodity Hledger.Data.Dates
    Hledger.Data.Journal Hledger.Data.Ledger Hledger.Data.MarketPrice
    Hledger.Data.Period Hledger.Data.PeriodicTransaction
    Hledger.Data.Posting Hledger.Data.RawOptions
    Hledger.Data.StringFormat Hledger.Data.Timeclock
    Hledger.Data.Transaction Hledger.Data.TransactionModifier
    Hledger.Data.Types Hledger.Query Hledger.Read Hledger.Read.Common
    Hledger.Read.CsvReader Hledger.Read.JournalReader
    Hledger.Read.TimeclockReader Hledger.Read.TimedotReader
    Hledger.Reports Hledger.Reports.BalanceHistoryReport
    Hledger.Reports.BalanceReport Hledger.Reports.BudgetReport
    Hledger.Reports.EntriesReport Hledger.Reports.MultiBalanceReports
    Hledger.Reports.PostingsReport Hledger.Reports.ReportOptions
    Hledger.Reports.ReportTypes Hledger.Reports.TransactionsReports
    Hledger.Utils Hledger.Utils.Color Hledger.Utils.Debug
    Hledger.Utils.Parse Hledger.Utils.Regex Hledger.Utils.String
    Hledger.Utils.Test Hledger.Utils.Text Hledger.Utils.Tree
    Hledger.Utils.UTF8IOCompat Text.Tabular.AsciiWide
hidden-modules: Text.Megaparsec.Custom Paths_hledger_lib
import-dirs: /usr/lib/ghc-8.6.5/site-local/hledger-lib-1.14.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hledger-lib-1.14.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hledger-lib-1.14.1
hs-libraries: HShledger-lib-1.14.1-CCFlRT6cyZWCBvFAl8C9cX
depends:
    Decimal-0.5.1-H2kU9PQoNIhDDGeZUlyXId
    Glob-0.10.0-53dKAknqnvt9l4cJJo9cnr
    ansi-terminal-0.9.1-7greAUREMxf1pgDTp3Pb1X array-0.5.3.0
    base-4.12.0.0 base-compat-batteries-0.10.5-KvYjlXLhf5S8nu3CG2PCKk
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    call-stack-0.1.0-J1eWgTNOnM4IGVyeW0v2YZ
    cassava-0.5.1.0-9dZezC1UxDTDHdgPv7p9Xy
    cassava-megaparsec-2.0.0-B7Z4umIU9AKLFsOLjbRH5f
    cmdargs-0.10.20-HFOpHQTj4XE8aEWjoI1u1 containers-0.6.0.1
    data-default-0.7.1.1-FxanJFkeYAJQ1iDuwiDPz deepseq-1.4.4.0
    directory-1.3.3.0 easytest-0.2.1-Fvr3pELpRTdDli5viSGCl3
    extra-1.6.18-EN0hv22Br2eFlf66cuOvbe
    file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke filepath-1.4.2.1
    hashtables-1.2.3.4-27kFAI3EbWD5WuakaktwlQ
    megaparsec-7.0.5-7nNPtHGYzPNBh8epow1r1w mtl-2.2.2
    old-time-1.1.0.3-HsoRJMkCHriE79r63Cxfu4 parsec-3.1.13.0
    parser-combinators-1.2.0-2keeVZyMyoBVuECNB2kOs
    pretty-show-1.9.5-4s9IVBWSe01IF3L4DDRCg8
    regex-tdfa-1.2.3.2-1zrqdepzFAcLwdkKMIY7hi
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji
    split-0.2.3.3-IbK4kxLa0sUBqxIH6ONm60
    tabular-0.2.2.7-FYVnBEx3xwsDpJzPJOu9nb template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    uglymemo-0.1.0.1-29YPrKIZHiw2b7IPpRwZ9C
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-hledger-lib/html/hledger-lib.haddock
haddock-html: /usr/share/doc/haskell-hledger-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
